@@ -149,3 +149,6 @@ ALLOW_ORIGIN = None
 
 # Enable capturing of JavaScript errors (Sentry internal errors)
 USE_JS_CLIENT = False
+
+# The alias for the cache backend (MUST be a compatible backend string for < 1.3)
+CACHE_BACKEND = 'dummy://'
