@@ -121,10 +121,17 @@ ADMIN_MEDIA_PREFIX = '/_admin_media/'
 
 BROKER_URL = "django://"
 
+CELERY_IGNORE_RESULT = True
+CELERY_SEND_EVENTS = False
+CELERY_RESULT_BACKEND = None
+CELERY_TASK_RESULT_EXPIRES = 1
+
+
 # Sentry and Raven configuration
 
 SENTRY_PUBLIC = False
 SENTRY_PROJECT = 1
+SENTRY_CACHE_BACKEND = 'default'
 
 EMAIL_SUBJECT_PREFIX = '[Sentry] '
 
