@@ -14,6 +14,7 @@ import time
 import uuid
 import urlparse
 from datetime import datetime
+from hashlib import md5
 from indexer.models import BaseIndex
 from picklefield.fields import PickledObjectField
 
@@ -28,7 +29,7 @@ from django.utils.translation import ugettext_lazy as _
 
 from sentry.conf import settings
 from sentry.manager import GroupManager, ProjectManager, \
-  MetaManager, InstanceMetaManager, SearchDocumentManager
+  MetaManager, InstanceMetaManager, SearchDocumentManager, BaseManager
 from sentry.utils import cached_property, \
   MockDjangoRequest
 from sentry.utils.models import Model, GzippedDictField
@@ -71,7 +72,9 @@ class Option(Model):
     key = models.CharField(max_length=64, unique=True)
     value = PickledObjectField()
 
-    objects = MetaManager()
+    objects = MetaManager(cache_fields=[
+        'key',
+    ])
 
 
 class Project(Model):
@@ -88,7 +91,9 @@ class Project(Model):
         (1, 'Hidden'),
     ), db_index=True)
 
-    objects = ProjectManager()
+    objects = ProjectManager(cache_fields=[
+        'pk',
+    ])
 
     def __unicode__(self):
         return u'#%s %r' % (self.pk, self.name)
@@ -102,7 +107,7 @@ class Project(Model):
 
     def merge_to(self, project):
         if not isinstance(project, Project):
-            project = Project.objects.get(pk=project)
+            project = Project.objects.get_from_cache(pk=project)
 
         for group in Group.objects.filter(project=self):
             try:
@@ -175,6 +180,50 @@ class ProjectOption(Model):
         return u'project=%s, key=%s, value=%s' % (self.project_id, self.key, self.value)
 
 
+class PendingProjectMember(Model):
+    """
+    Identifies relationships between projects and pending invites.
+    """
+    project = models.ForeignKey(Project, related_name="pending_member_set")
+    email = models.EmailField()
+    type = models.IntegerField(choices=MEMBER_TYPES, default=globals().get(settings.DEFAULT_PROJECT_ACCESS))
+    date_added = models.DateTimeField(default=datetime.now)
+
+    class Meta:
+        unique_together = (('project', 'email'),)
+
+    def __unicode__(self):
+        return u'project=%s, email=%s, type=%s' % (self.project_id, self.email, self.get_type_display())
+
+    @property
+    def token(self):
+        checksum = md5()
+        for x in (str(self.project_id), self.email, settings.KEY):
+            checksum.update(x)
+        return checksum.hexdigest()
+
+    def send_invite_email(self):
+        from django.core.mail import send_mail
+        from sentry.web.helpers import render_to_string
+
+        context = {
+            'email': self.email,
+            'project': self.project,
+            'url': '%s%s' % (settings.URL_PREFIX, reverse('sentry-accept-invite', kwargs={
+                'member_id': self.id,
+                'token': self.token,
+            })),
+        }
+        body = render_to_string('sentry/emails/member_invite.txt', context)
+
+        try:
+            send_mail('%s Invite to join project: %s' % (settings.EMAIL_SUBJECT_PREFIX, self.project.name),
+                body, settings.SERVER_EMAIL, [self.email],
+                fail_silently=False)
+        except Exception, e:
+            logger = logging.getLogger('sentry.mail.errors')
+            logger.exception(e)
+
 class ProjectMember(Model):
     """
     Identifies relationships between projects and users, including
@@ -182,11 +231,17 @@ class ProjectMember(Model):
     """
     project = models.ForeignKey(Project, related_name="member_set")
     user = models.ForeignKey(User, related_name="sentry_project_set")
+    is_active = models.BooleanField(default=True)
     public_key = models.CharField(max_length=32, unique=True, null=True)
     secret_key = models.CharField(max_length=32, unique=True, null=True)
     type = models.IntegerField(choices=MEMBER_TYPES, default=globals().get(settings.DEFAULT_PROJECT_ACCESS))
     date_added = models.DateTimeField(default=datetime.now)
 
+    objects = BaseManager(cache_fields=[
+        'public_key',
+        'secret_key',
+    ])
+
     class Meta:
         unique_together = (('project', 'user'),)
 
@@ -222,6 +277,8 @@ class ProjectDomain(Model):
     project = models.ForeignKey(Project, related_name="domain_set")
     domain = models.CharField(max_length=128)
 
+    objects = BaseManager()
+
     class Meta:
         unique_together = (('project', 'domain'),)
 
@@ -261,6 +318,10 @@ class View(Model):
     verbose_name = models.CharField(max_length=200, null=True)
     verbose_name_plural = models.CharField(max_length=200, null=True)
 
+    objects = BaseManager(cache_fields=[
+        'path',
+    ])
+
     def __unicode__(self):
         return self.path
 
@@ -394,6 +455,9 @@ class Event(MessageBase):
     server_name = models.CharField(max_length=128, db_index=True, null=True)
     site = models.CharField(max_length=128, db_index=True, null=True)
 
+    objects = BaseManager()
+
+
     class Meta:
         verbose_name = _('message')
         verbose_name_plural = _('messages')
@@ -469,6 +533,8 @@ class GroupBookmark(Model):
     # namespace related_name on User since we dont own the model
     user = models.ForeignKey(User, related_name="sentry_bookmark_set")
 
+    objects = BaseManager()
+
     class Meta:
         # composite index includes project for efficient queries
         unique_together = (('project', 'user', 'group'),)
@@ -482,6 +548,8 @@ class FilterValue(Model):
     key = models.CharField(choices=FILTER_KEYS, max_length=32)
     value = models.CharField(max_length=200)
 
+    objects = BaseManager()
+
     class Meta:
         unique_together = (('project', 'key', 'value'),)
 
@@ -502,6 +570,8 @@ class MessageFilterValue(Model):
     last_seen = models.DateTimeField(default=datetime.now, db_index=True, null=True)
     first_seen = models.DateTimeField(default=datetime.now, db_index=True, null=True)
 
+    objects = BaseManager()
+
     class Meta:
         unique_together = (('project', 'key', 'value', 'group'),)
 
@@ -524,6 +594,8 @@ class MessageCountByMinute(Model):
     time_spent_total = models.FloatField(default=0)
     time_spent_count = models.IntegerField(default=0)
 
+    objects = BaseManager()
+
     class Meta:
         unique_together = (('project', 'group', 'date'),)
 
@@ -544,6 +616,8 @@ class ProjectCountByMinute(Model):
     time_spent_total = models.FloatField(default=0)
     time_spent_count = models.IntegerField(default=0)
 
+    objects = BaseManager()
+
     class Meta:
         unique_together = (('project', 'date'),)
 
@@ -568,6 +642,8 @@ class SearchToken(Model):
     token = models.CharField(max_length=128)
     times_seen = models.PositiveIntegerField(default=1)
 
+    objects = BaseManager()
+
     class Meta:
         unique_together = (('document', 'field', 'token'),)
 
