@@ -15,12 +15,23 @@ from sentry.plugins import register
 from sentry.plugins.bases.notify import NotifyPlugin, NotifyConfigurationForm
 import re
 
-import pynliner
+from pynliner import Pynliner
 
 NOTSET = object()
 split_re = re.compile(r'\s*,\s*|\s+')
 
 
+class UnicodeSafePynliner(Pynliner):
+    def _get_output(self):
+        """
+        Generate Unicode string of `self.soup` and set it to `self.output`
+
+        Returns self.output
+        """
+        self.output = unicode(self.soup)
+        return self.output
+
+
 class MailConfigurationForm(NotifyConfigurationForm):
     send_to = forms.CharField(label=_('Send to'), required=False,
         help_text=_('Enter one or more emails separated by commas or lines.'),
@@ -39,6 +50,7 @@ class MailConfigurationForm(NotifyConfigurationForm):
 class MailProcessor(NotifyPlugin):
     title = _('Mail')
     conf_key = 'mail'
+    slug = 'mail'
     project_conf_form = MailConfigurationForm
 
     def __init__(self, min_level=NOTSET, include_loggers=NOTSET, exclude_loggers=NOTSET,
@@ -65,7 +77,7 @@ class MailProcessor(NotifyPlugin):
         self.send_to_admins = send_to_admins
         self.subject_prefix = settings.EMAIL_SUBJECT_PREFIX
 
-    def _send_mail(self, subject, body, html_body=None, project=None, fail_silently=True):
+    def _send_mail(self, subject, body, html_body=None, project=None, fail_silently=False):
         send_to = self.get_send_to(project)
         subject_prefix = self.get_option('subject_prefix', project) or self.subject_prefix
 
@@ -86,13 +98,13 @@ class MailProcessor(NotifyPlugin):
         send_to_list = self.get_option('send_to', project) or []
 
         if isinstance(send_to_list, basestring):
-            send_to_list = send_to_list.split(',')
+            send_to_list = [s.strip() for s in send_to_list.split(',')]
 
         send_to_list.extend(super(MailProcessor, self).get_send_to(project))
 
         return filter(bool, set(send_to_list))
 
-    def notify_users(self, group, event, fail_silently=True):
+    def notify_users(self, group, event, fail_silently=False):
         project = group.project
 
         interface_list = []
@@ -102,7 +114,7 @@ class MailProcessor(NotifyPlugin):
                 continue
             interface_list.append((interface.get_title(), body))
 
-        subject = '[%s] %s: %s' % (project.name, event.get_level_display().upper(), event.message)
+        subject = '[%s] %s: %s' % (project.name.encode('utf-8'), event.get_level_display().upper(), event.message.encode('utf-8'))
 
         link = '%s/%d/group/%d/' % (settings.URL_PREFIX, group.project_id, group.id)
 
@@ -112,12 +124,12 @@ class MailProcessor(NotifyPlugin):
             'link': link,
             'interfaces': interface_list,
         })
-        html_body = pynliner.fromString(render_to_string('sentry/emails/error.html', {
+        html_body = UnicodeSafePynliner().from_string(render_to_string('sentry/emails/error.html', {
             'group': group,
             'event': event,
             'link': link,
             'interfaces': interface_list,
-        }))
+        })).run()
 
         self._send_mail(
             subject=subject,
