@@ -47,12 +47,28 @@ urlpatterns = patterns('',
 
     url(r'^projects/$', projects.project_list, name='sentry-project-list'),
     url(r'^projects/new/$', projects.new_project, name='sentry-new-project'),
-    url(r'^projects/(?P<project_id>\d+)/edit/$', projects.manage_project, name='sentry-manage-project'),
-    url(r'^projects/(?P<project_id>\d+)/plugins/(?P<slug>[\w_-]+)/$', projects.configure_project_plugin, name='sentry-configure-project-plugin'),
-    url(r'^projects/(?P<project_id>\d+)/remove/$', projects.remove_project, name='sentry-remove-project'),
-    url(r'^projects/(?P<project_id>\d+)/members/new/$', projects.new_project_member, name='sentry-new-project-member'),
-    url(r'^projects/(?P<project_id>\d+)/members/(?P<member_id>\d+)/edit/$', projects.edit_project_member, name='sentry-edit-project-member'),
-    url(r'^projects/(?P<project_id>\d+)/members/(?P<member_id>\d+)/remove/$', projects.remove_project_member, name='sentry-remove-project-member'),
+    url(r'^projects/(?P<project_id>\d+)/edit/$', projects.manage_project,
+        name='sentry-manage-project'),
+    url(r'^projects/(?P<project_id>\d+)/plugins/(?P<slug>[\w_-]+)/$', projects.configure_project_plugin,
+        name='sentry-configure-project-plugin'),
+    url(r'^projects/(?P<project_id>\d+)/remove/$', projects.remove_project,
+        name='sentry-remove-project'),
+    url(r'^projects/(?P<project_id>\d+)/members/new/$', projects.new_project_member,
+        name='sentry-new-project-member'),
+    url(r'^projects/(?P<project_id>\d+)/members/(?P<member_id>\d+)/edit/$', projects.edit_project_member,
+        name='sentry-edit-project-member'),
+    url(r'^projects/(?P<project_id>\d+)/members/(?P<member_id>\d+)/remove/$', projects.remove_project_member,
+        name='sentry-remove-project-member'),
+    url(r'^projects/(?P<project_id>\d+)/members/(?P<member_id>\d+)/suspend/$', projects.suspend_project_member,
+        name='sentry-suspend-project-member'),
+    url(r'^projects/(?P<project_id>\d+)/members/(?P<member_id>\d+)/restore/$', projects.restore_project_member,
+        name='sentry-restore-project-member'),
+    url(r'^projects/(?P<project_id>\d+)/members/pending/(?P<member_id>\d+)/remove/$', projects.remove_pending_project_member,
+        name='sentry-remove-pending-project-member'),
+    url(r'^projects/(?P<project_id>\d+)/members/pending/(?P<member_id>\d+)/reinvite/$', projects.reinvite_pending_project_member,
+        name='sentry-reinvite-pending-project-member'),
+    url(r'^accept/(?P<member_id>\d+)/(?P<token>\w+)/$', projects.accept_invite,
+        name='sentry-accept-invite'),
 
     # Global
 
